@@ -12,7 +12,7 @@ from django.template import loader
 from djangoldp_i18n.views import I18nLDPViewSet
 
 class LearningOutcome (Model) :
-    name = models.CharField(max_length=256, verbose_name="Learning outcome")
+    name = models.CharField(max_length=256, verbose_name="Learning outcome", null=True, blank=True)
     
     class Meta:
         rdf_type = 'coopstarter:skills'
@@ -20,50 +20,52 @@ class LearningOutcome (Model) :
         depth = 1
 
     def __str__(self):
-        return self.name
+        return str(self.name)
 
 class InterfaceLanguage (Model):
-    code = models.CharField(max_length=2, verbose_name="ISO Code")
-    name = models.CharField(max_length=64, verbose_name="Language name")
+    code = models.CharField(max_length=2, verbose_name="ISO Code", null=True, blank=True)
+    name = models.CharField(max_length=64, verbose_name="Language name", null=True, blank=True)
     
     class Meta:
         rdf_type = 'coopstarter:interfacelanguage'
 
     def __str__(self):
-        return self.name
+        return str(self.name) + '(' + str(self.code) + ')'
 
 class Country (Model):
-    code = models.CharField(max_length=2, verbose_name="ISO Code")
-    name = models.CharField(max_length=64, verbose_name="Country name")
+    code = models.CharField(max_length=2, verbose_name="ISO Code", null=True, blank=True)
+    name = models.CharField(max_length=64, verbose_name="Country name", null=True, blank=True)
     
     class Meta:
         rdf_type = 'coopstarter:country'
 
     def __str__(self):
-        return self.name
+        return str(self.name) + '(' + str(self.code) + ')'
 
 class Language (Model):
-    code = models.CharField(max_length=2, verbose_name="ISO Code")
-    name = models.CharField(max_length=64, verbose_name="Language name")
+    code = models.CharField(max_length=2, verbose_name="ISO Code", null=True, blank=True)
+    name = models.CharField(max_length=64, verbose_name="Language name", null=True, blank=True)
 
     class Meta:
         rdf_type = 'coopstarter:language'
 
     def __str__(self):
-        return self.name
+        return str(self.name) + '(' + str(self.code) + ')'
 
 class Organisation (Model):
-    name = models.CharField(max_length=128, verbose_name="Name")
-    website = models.CharField(max_length=4096, verbose_name="Website")
+    name = models.CharField(max_length=128, verbose_name="Name", null=True, blank=True)
+    website = models.CharField(max_length=4096, verbose_name="Website", null=True, blank=True)
 
     class Meta:
         rdf_type = 'coopstarter:organisation'
 
     def __str__(self):
-        return self.name
+        if self.name is None or self.name == '':
+            return str(self.website)
+        return str(self.name)
 
 class Step (Model):
-    name = models.CharField(max_length=128, verbose_name="Name")
+    name = models.CharField(max_length=128, verbose_name="Name", null=True, blank=True)
     order = models.IntegerField(verbose_name="Order", blank=True, null=True, default=0)
     
     class Meta:
@@ -76,10 +78,10 @@ class Step (Model):
         depth = 1
     
     def __str__(self):
-        return self.name
+        return str(self.name) + '(' + str(self.order) + ')'
 
 class Format (Model):
-    name = models.CharField(max_length=128, verbose_name="Title")
+    name = models.CharField(max_length=128, verbose_name="Title", blank=True, null=True)
 
     class Meta:
         rdf_type = 'coopstarter:format'
@@ -87,10 +89,10 @@ class Format (Model):
         depth = 1
 
     def __str__(self):
-        return self.name
+        return str(self.name)
 
 class Field (Model):
-    name = models.CharField(max_length=128, verbose_name="Title")
+    name = models.CharField(max_length=128, verbose_name="Title", null=True, blank=True)
 
     class Meta:
         rdf_type = 'coopstarter:field'
@@ -98,10 +100,10 @@ class Field (Model):
         depth = 1
 
     def __str__(self):
-        return self.name
+        return str(self.name)
 
 class Type (Model):
-    name = models.CharField(max_length=128, verbose_name="Title")
+    name = models.CharField(max_length=128, verbose_name="Title", null=True, blank=True)
 
     class Meta:
         rdf_type = 'coopstarter:resourcetype'
@@ -109,10 +111,10 @@ class Type (Model):
         depth = 1
 
     def __str__(self):
-        return self.name
+        return str(self.name)
 
 class Target (Model):
-    name = models.CharField(max_length=128, verbose_name="name")
+    name = models.CharField(max_length=128, verbose_name="name", blank=True, null=True)
     value = models.CharField(max_length=128, verbose_name="value", blank=True, null=True)
 
     class Meta:
@@ -121,10 +123,10 @@ class Target (Model):
         depth = 1
 
     def __str__(self):
-        return self.name
+        return str(self.name)
 
 class SharingCriteria (Model):
-    name = models.CharField(max_length=128, verbose_name="name")
+    name = models.CharField(max_length=128, verbose_name="name", blank=True, null=True)
     value = models.CharField(max_length=128, verbose_name="value", blank=True, null=True)
 
     class Meta:
@@ -133,12 +135,13 @@ class SharingCriteria (Model):
         depth = 1
 
     def __str__(self):
-        return self.name
+        return str(self.name)
 
 
 class Searcher(Model):
-    user = models.OneToOneField(settings.AUTH_USER_MODEL, related_name="searcher_profile", on_delete=models.DO_NOTHING)
-    organisation = models.ForeignKey(Organisation, null=True, on_delete=models.DO_NOTHING, related_name="searchers")
+    user = models.OneToOneField(settings.AUTH_USER_MODEL, related_name="searcher_profile", on_delete=models.CASCADE,
+                                null=True)
+    organisation = models.ForeignKey(Organisation, null=True, on_delete=models.CASCADE, related_name="searchers")
     
     class Meta:
         auto_author = 'user'
@@ -153,13 +156,18 @@ class Searcher(Model):
         depth = 1
     
     def __str__(self):
-        return self.user.get_full_name()
+        if self.user is not None:
+            return self.user.get_full_name()
+        if self.organisation is not None:
+            return str(self.organisation)
+        return str(None)
 
 class Contributor(Model):
-    user = models.OneToOneField(settings.AUTH_USER_MODEL, related_name="contributor_profile", on_delete=models.DO_NOTHING)
+    user = models.OneToOneField(settings.AUTH_USER_MODEL, related_name="contributor_profile", on_delete=models.CASCADE,
+                                null=True)
     phone = models.CharField(max_length=25, null=True, blank=True, verbose_name='Phone number')
-    organisation = models.ForeignKey(Organisation, null=True, on_delete=models.DO_NOTHING, related_name="contributors")
-    country = models.ForeignKey(Country, null=True, related_name="contributors", on_delete=models.DO_NOTHING)
+    organisation = models.ForeignKey(Organisation, null=True, on_delete=models.SET_NULL, related_name="contributors")
+    country = models.ForeignKey(Country, null=True, related_name="contributors", on_delete=models.SET_NULL)
     languages = models.ManyToManyField(Language, blank=True)
 
     headline = models.CharField(max_length=256, blank=True, null=True, verbose_name='Headline or current position')
@@ -191,12 +199,14 @@ class Contributor(Model):
         depth = 1
 
     def __str__(self):
-        return self.user.get_full_name()
+        if self.user is not None:
+            return self.user.get_full_name()
+        return str(self.urlid)
 
 class Review (Model):
-    comment =  models.TextField(verbose_name="Comment", blank=True)
+    comment =  models.TextField(verbose_name="Comment", blank=True, null=True)
     status = models.CharField(max_length=32, choices=(('pending', 'Pending'), ('inappropriate', 'Inappropriate'), ('validated', 'Validated'), ('to_improve', 'Improvement required')), verbose_name="Resource status", blank=True, null=True)
-    reviewer = models.ForeignKey(settings.AUTH_USER_MODEL, null=True, on_delete=models.DO_NOTHING, related_name='reviews')
+    reviewer = models.ForeignKey(settings.AUTH_USER_MODEL, null=True, on_delete=models.SET_NULL, related_name='reviews')
 
     class Meta:
         owner_field = 'reviewer'
@@ -210,19 +220,19 @@ class Review (Model):
         depth = 1
 
     def __str__(self):
-        return self.comment
+        return '(' + str(self.status) + ')' + str(self.comment)
 
 class Resource (Model):
     # Mandatory Fields
-    name = models.CharField(max_length=256, verbose_name="Title")
+    name = models.CharField(max_length=256, verbose_name="Title", blank=True, null=True)
 
-    format = models.ForeignKey(Format, null=True, related_name='resources', on_delete=models.DO_NOTHING)
+    format = models.ForeignKey(Format, null=True, related_name='resources', on_delete=models.SET_NULL)
     publication_year = models.IntegerField(verbose_name="Publication Year", null=True, blank=True)
     languages = models.ManyToManyField(Language, blank=True, verbose_name="Languages", related_name='resources')
     fields = models.ManyToManyField(Field, blank=True, verbose_name="Fields", related_name='resources')
-    country = models.ForeignKey(Country, null=True, on_delete=models.DO_NOTHING)
-    uri = models.CharField(max_length=4086, verbose_name="Location/weblink")
-    resource_author = models.CharField(max_length=256, verbose_name="Author")
+    country = models.ForeignKey(Country, null=True, on_delete=models.SET_NULL)
+    uri = models.CharField(max_length=4086, verbose_name="Location/weblink", blank=True, null=True)
+    resource_author = models.CharField(max_length=256, verbose_name="Author", blank=True, null=True)
     skills = models.ManyToManyField(LearningOutcome, blank=True, verbose_name="Learning outcomes/skills", related_name='resources')
 
     # Complementary fields
@@ -231,17 +241,17 @@ class Resource (Model):
     preview_image = models.URLField(blank=True, null=True)
 
     # Classification Fields
-    target = models.ForeignKey(Target, verbose_name="Target audience", blank=True, null=True, on_delete=models.DO_NOTHING)
+    target = models.ForeignKey(Target, verbose_name="Target audience", blank=True, null=True, on_delete=models.SET_NULL)
     type = models.ManyToManyField(Type, blank=True, verbose_name="Type of content", related_name='resources')
-    sharing = models.ForeignKey(SharingCriteria, blank=True, null=True, verbose_name="Sharing profile", related_name='resources', on_delete=models.DO_NOTHING)
+    sharing = models.ForeignKey(SharingCriteria, blank=True, null=True, verbose_name="Sharing profile", related_name='resources', on_delete=models.SET_NULL)
     steps = models.ManyToManyField(Step, blank=True, related_name="resources")
 
     # Relations to other models
-    submitter = models.ForeignKey(settings.AUTH_USER_MODEL, null=True, on_delete=models.DO_NOTHING, related_name='resources')
+    submitter = models.ForeignKey(settings.AUTH_USER_MODEL, null=True, on_delete=models.SET_NULL, related_name='resources')
     related = models.ManyToManyField("self", blank=True)
     conversations = models.ManyToManyField(Conversation, blank=True, related_name='resources')
     likes = models.ManyToManyField(Like, blank=True, related_name='resources')
-    review = models.OneToOneField(Review, blank=True, null=True, verbose_name="Associated review", related_name='resource', on_delete=models.DO_NOTHING)
+    review = models.OneToOneField(Review, blank=True, null=True, verbose_name="Associated review", related_name='resource', on_delete=models.SET_NULL)
  
     class Meta:
         auto_author='submitter'
@@ -263,25 +273,25 @@ class Resource (Model):
         depth = 1
 
     def __str__(self):
-        return self.name
+        return str(self.name)
 
 class Request (Model):
     # Mandatory Fields
-    name = models.CharField(max_length=128, verbose_name="Title")
-    description = models.TextField(verbose_name="Description")
+    name = models.CharField(max_length=128, verbose_name="Title", null=True, blank=True)
+    description = models.TextField(verbose_name="Description", null=True, blank=True)
     status = models.CharField(max_length=32, verbose_name="Status", choices=(('pending', 'Pending'), ('validated', 'Validated')), default="pending")
     
-    language = models.ForeignKey(Language, blank=True, verbose_name="Language", on_delete=models.DO_NOTHING)
+    language = models.ForeignKey(Language, blank=True, verbose_name="Language", on_delete=models.SET_NULL, null=True)
     fields = models.ManyToManyField(Field, blank=True)
-    country = models.ForeignKey(Country, null=True, on_delete=models.DO_NOTHING)
+    country = models.ForeignKey(Country, null=True, on_delete=models.SET_NULL)
 
-    organisation = models.ForeignKey(Organisation, on_delete=models.DO_NOTHING, related_name="requests")
-    skills = models.TextField(verbose_name="Learning outcomes/skills")
+    organisation = models.ForeignKey(Organisation, on_delete=models.SET_NULL, related_name="requests", null=True)
+    skills = models.TextField(verbose_name="Learning outcomes/skills", null=True, blank=True)
     
-    submitter = models.ForeignKey(settings.AUTH_USER_MODEL, null=True, on_delete=models.DO_NOTHING, related_name='requests')
-    reviewer = models.ForeignKey(settings.AUTH_USER_MODEL, null=True, on_delete=models.DO_NOTHING, related_name='reviewed_requests')
+    submitter = models.ForeignKey(settings.AUTH_USER_MODEL, null=True, on_delete=models.SET_NULL, related_name='requests')
+    reviewer = models.ForeignKey(settings.AUTH_USER_MODEL, null=True, on_delete=models.SET_NULL, related_name='reviewed_requests')
 
-    created_on = models.DateTimeField(default=timezone.now)
+    created_on = models.DateTimeField(default=timezone.now, null=True)
 
     class Meta:
         ordering = ['-created_on']
@@ -298,11 +308,12 @@ class Request (Model):
         depth = 1
         
     def __str__(self):
-        return self.name
+        return str(self.name)
 
 class BrokenLink(Model):
-    submitter = models.ForeignKey(settings.AUTH_USER_MODEL, on_delete=models.DO_NOTHING, related_name="brokenlink_submitter")
-    resource = models.ForeignKey(Resource, null=True, on_delete=models.DO_NOTHING, related_name="brokenlink_resource")
+    submitter = models.ForeignKey(settings.AUTH_USER_MODEL, on_delete=models.SET_NULL, related_name="brokenlink_submitter",
+                                  null=True, blank=True)
+    resource = models.ForeignKey(Resource, null=True, on_delete=models.SET_NULL, related_name="brokenlink_resource")
     
     class Meta:
         auto_author = 'submitter'
