@@ -17,7 +17,7 @@ class ValidatedResourcesByStepViewSet(I18nLDPViewSet):
     # Additional filter criteria: , target__value=target
     return super().get_queryset(*args, **kwargs)\
           .filter(steps__in=step_id, review__status='validated')\
-          .exclude(submitter__username=self.request.user.username)
+          .exclude(is_backlink=True)
 
 class PendingResourcesViewSet(I18nLDPViewSet):
   model = Resource
@@ -27,4 +27,4 @@ class PendingResourcesViewSet(I18nLDPViewSet):
     # , language__in=self.request.user.contributor_profile.languages.all(), fields__in=self.request.user.contributor_profile.fields.all()
     return super().get_queryset(*args, **kwargs)\
           .filter(review__status='pending')\
-          .exclude(submitter__username=self.request.user.username)
\ No newline at end of file
+          .exclude(submitter__username=self.request.user.username, is_backlink=True)
\ No newline at end of file
